==> haskell-tostring-0.2.1.1-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tostring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tostring
version:              0.2.1.1
visibility:           public
id:                   tostring-0.2.1.1-B9Qwwst6BfS6sPfRSKprPf
key:                  tostring-0.2.1.1-B9Qwwst6BfS6sPfRSKprPf
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk B.V.
synopsis:             The ToString class
description:          A type class for converting text types to String.
category:             Data
abi:                  caeca4408c20fc6fd4e5bd539d4a75fd
exposed:              True
exposed-modules:      Data.String.ToString
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tostring
hs-libraries:         HStostring-0.2.1.1-B9Qwwst6BfS6sPfRSKprPf
depends:
    base-4.18.2.1 case-insensitive-1.2.1.0-5HTh5m1rt1RHDEKgWxawKc
    text-2.0.2 utf8-string-1.0.2-4PcjKdTUnsVIUZCxTUoFbK

haddock-interfaces:   /usr/share/doc/haskell-tostring/html/tostring.haddock
haddock-html:         /usr/share/doc/haskell-tostring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tostring-0.2.1.1-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tostring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tostring
version:              0.2.1.1
visibility:           public
id:                   tostring-0.2.1.1-6Hs9qXpcbsT3swqjLHBuDy
key:                  tostring-0.2.1.1-6Hs9qXpcbsT3swqjLHBuDy
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk B.V.
synopsis:             The ToString class
description:          A type class for converting text types to String.
category:             Data
abi:                  4b7540adb1952a689c69c1208f040680
exposed:              True
exposed-modules:      Data.String.ToString
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tostring-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tostring
hs-libraries:         HStostring-0.2.1.1-6Hs9qXpcbsT3swqjLHBuDy
depends:
    base-4.18.2.1 case-insensitive-1.2.1.0-26iNgmqHMOsJk4yniKxDB2
    text-2.0.2 utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-tostring/html/tostring.haddock
haddock-html:         /usr/share/doc/haskell-tostring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
